@@ -16,6 +16,27 @@
   pred
 }
 
+as_rquery.vtreat_cat_d <- function(tstep, 
+                                   ...,
+                                   var_restriction) {
+  if(!requireNamespace("rquery", quietly = TRUE)) {
+    stop("vtreat::as_rquery.vtreat_cat_d treatmentplan requires the rquery package")
+  }
+  wrapr::stop_if_dot_args(substitute(list(...)), "vtreat::as_rquery.vtreat_cat_d")
+  if((!is.null(var_restriction)) && (!(tstep$newvars %in% var_restriction))) {
+    return(NULL)
+  }
+  args <- tstep$args
+  rquery_code_categorical(colname = tstep$origvar, 
+                          resname = tstep$newvars,
+                          coding_levels = names(args$scores),
+                          effect_values = args$scores,
+                          levRestriction = args$levRestriction,
+                          default_value = 0.0)
+}
+
+
+
 # build a deviation fact
 # see: http://www.win-vector.com/blog/2012/07/modeling-trick-impact-coding-of-categorical-variables-with-many-levels/
 .mkCatD <- function(origVarName,vcolin,rescol,smFactor,levRestriction,weights) {
@@ -36,7 +57,7 @@
   }
   scores <- as.list(scores)
   scores <- scores[names(scores)!='zap'] # don't let zap code
-  newVarName <- make.names(paste(origVarName,'catD',sep='_'))
+  newVarName <- vtreat_make_names(paste(origVarName,'catD',sep='_'))
   treatment <- list(origvar=origVarName,
                     newvars=newVarName,
                     f=.catD,
@@ -52,7 +73,7 @@
   if(!.has.range.cn(pred)) {
     return(NULL)
   }
-  class(treatment) <- 'vtreatment'
+  class(treatment) <- c('vtreat_cat_d', 'vtreatment')
   treatment$scales <- linScore(newVarName,pred,rescol,weights)
   treatment
 }
